@@ -80,7 +80,7 @@ def main():
             args.model, class_names=dataset.CLASSES, device_id=0)
     else:
         print('Unknown backend: {}.'.format(args.model))
-        exit()
+        exit(1)
 
     model = MMDataParallel(model, device_ids=[0])
     model.CLASSES = dataset.CLASSES
@@ -114,3 +114,15 @@ def main():
 
 if __name__ == '__main__':
     main()
+
+    # Following strings of text style are from colorama package
+    bright_style, reset_style = '\x1b[1m', '\x1b[0m'
+    red_text, blue_text = '\x1b[31m', '\x1b[34m'
+    white_background = '\x1b[107m'
+
+    msg = white_background + bright_style + red_text
+    msg += 'DeprecationWarning: This tool will be deprecated in future. '
+    msg += blue_text + 'Welcome to use the unified model deployment toolbox '
+    msg += 'MMDeploy: https://github.com/open-mmlab/mmdeploy'
+    msg += reset_style
+    warnings.warn(msg)
